#ifndef _DSO1200DLL_H_
#define _DSO1200DLL_H_
/*******************************************/
#ifdef DLL_API
#else
#define DLL_API extern "C" _declspec(dllimport)
#endif
#define WINAPI __stdcall


/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**************/
typedef unsigned char	BOOLEAN;
typedef unsigned char	INT8U;                    /* Unsigned  8 bit quantity                           */
typedef signed   char	INT8S;                    /* Signed    8 bit quantity                           */
typedef unsigned short	INT16U;                   /* Unsigned 16 bit quantity                           */
typedef signed short	INT16S;                   /* Signed   16 bit quantity                           */
typedef unsigned long	INT32U;                   /* Unsigned 32 bit quantity                           */
typedef signed   long	INT32S;                   /* Signed   32 bit quantity                           */
typedef float			FP32;                     /* Single precision floating point                    */
typedef double			FP64;                     /* Double precision floating point                    */

typedef INT32U HTSTATUS; ///The status of DSO
#define HT_OK		0
#define HT_ERROR	1
	// HTSTATUS
	// 0 : Success
	// 1 : No item
/*The device information*/
typedef struct _HT_DEVICE_INFO 
{
	char szName[20];		//the name of DSO
	char szSerial[20];		//the serial number of DSO
	INT16U iFirmVersion;	//the firmware's version
	INT16U iHardVersion[4]; //the hardware verison, the hardware verison, HardVersion[0]-PCB version, HardVersion[1]-mcu 1# version, 
							//HardVersion[2]-mcu 2# version, HardVersion[3]-Lan version.
	INT32U iDate;			//Factory date-0~7:Day,8~15:Month,16~31:Year
} HT_DEVICE_INFO,*PHT_DEVICE_INFO;


//HT_DEVICE_ID -- 
//0~15 : the index of machine. the machine which connected to PC first will be set as 0, the second is 1, and so on
//16~31: the communiate mode. 0: USB, 1:COM, 2:LAN
typedef unsigned long  HT_DEVICE_ID; 
//Make the HT_DEVICE_ID auto
#define CREATE_DEVID(id,mode) ( (id) | ( (mode) << 16 ) )
#define DEV_USB		0
#define DEV_COM		1
#define DEV_LAN		2

#define HT_DSO		0
#define HT_DMM		1
#define HT_DDS		2
/********************/
#define MAX_DEV_NUM 16	//max usb connect 
/***********************************************/
//Function
#define USB_NO_DEVICE			0
#define USB_HAVE_DEVICE			1
//Function
/***********************************************************
*Function:		HTGetUSBDeviceList
*Description:	Get the number of devices connecting to the PC
*Parameters:	INT8U* pUsbStatus: The usb status array. The size of the array is 16
				for example: if the array return as {1, 0, 1, 1, 0, 0, 0...}, it means there are 
				there equipments connecting to the PC, and the index of the there is 0 , 2 and 3.
*Return: 		the number of equipments connecting to the PC 
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API INT32U WINAPI HTGetUSBDeviceList(INT8U* usbList);
/***********************************************************
*Function:		HTGetDeviceInfo
*Description:	Get the device's information 
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID. 
				PHT_DEVICE_INFO pHTDeviceInfo:	the pointer to the information struct.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI HTGetDeviceInfo(HT_DEVICE_ID iDeviceID,PHT_DEVICE_INFO pHTDeviceInfo);
/***********************************************************
*Function:		HTScreenShoot
*Description:	Screen shoot and save the bitmap file under the pszPath
*Parameters:	HT_DEVICE_ID iDeivceID:		the id of the device which is made by CREATE_DEVID.
				char* pszPath:				the path of the bitmap to save, for example: "/opt/test.bmp"
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI HTScreenShoot(HT_DEVICE_ID iDeviceID,char* pszPath);
/***********************************************************
*Function:		HTShutDown
*Description:	Shut down or reset the equipment.
*Parameters:	HT_DEVICE_ID iDeivceID:		the id of the device which is made by CREATE_DEVID.
				INT8U iMode:				0: Shutdown, 1: reset
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI HTShutDown(HT_DEVICE_ID iDeviceID, INT8U iMode);
/***********************************************************
*Function:		HTChangeFunction
*Description:	Change the function between Scope, measurement and waveform generator.
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iFunction:		0: Scope, 1: measurement, 2: waveform generator
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI HTChangeFunction(HT_DEVICE_ID iDeviceID,INT8U iFunction);
/***********************************************************
*Function:		HTShowMenu
*Description:	Show or hide the menu in the firmware
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				BOOLEAN bShow:					0: Hide, 1: Show
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI HTShowMenu(HT_DEVICE_ID iDeviceID,BOOLEAN bShow);
/***********************************************************
*Function:		HTUSBCheckConnect
*Description:	Check Whether the usb is connecting or not
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-11-02
**********************************************************/
DLL_API HTSTATUS WINAPI HTUSBCheckConnect(HT_DEVICE_ID iDeviceID);
/***********************************************************
*Function:		HTGetFunction
*Description:	Get the DSO function
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
*Return: 		0:DSO, 1:DMM, 2:DDS(only 8000 series)
*Author:		Hantek
*Create Date:	2009-11-02
**********************************************************/
DLL_API int WINAPI HTGetFunction(HT_DEVICE_ID iDeviceID);
/*******************************************/

///////////////////DSO
/*Vertical trigger system definition*/
typedef struct _TRIGGER
{
	USHORT Mode;			/*Trigger Mode:		0: Edge trigger, 1: pulse trigger*/	
	USHORT Source;			/*Trigger Source:	0: CH1,	1: CH2*/
	USHORT Sweep;			/*Trigger sweep:	0: Auto, 1:Normal, 2:Single*/
	USHORT Slope;			/*Trigger Slope:	0: Rising, 1:Falling */
	USHORT HFReject;		/*HF Reject:		0: OFF,	1: ON*/
	USHORT PWCondition;		/*Pulse when condition: 0: +Less, 1: +Equal, 2: +More, 3: -Less, 4: -Equal, 5: -More*/
	ULONG pluseValue;		/*Pulse setting value: the unit is ns/5, 
								for example: if the value is 1000, the pulse setting is 5ms */
}TRIGGER;
/*Math Channel parameter*/
typedef struct _MATH
{
	USHORT MathOperate;		/*Math operator:	0: +, 1: -, 2: *, 3: /, 4: FFT*/
	USHORT MathSource[2];	/*The two sources of the math*/
	USHORT fftWindow;		/*FFT Window, 0:Rectangle, 1:Hanning, 2:Hamming, 3:Blackman*/
	USHORT fftSource;		/*FFT Source, 0: CH1, 1:CH2*/
	USHORT fftScale;		/*FFT Scale, 0:Vrms, 1:dBVrms*/
	USHORT fftSplite;		/*FFT Splite*/
	USHORT fftDB;			/*db index in the array, {1, 2, 5, 10, 20, 50, 100} (dB/div)*/
}MATH;
typedef struct _CHANNEL
{
	USHORT enable;			/*Enable of disable, 0: Disable, 1:Enable*/
	USHORT voltDivIndex;		/*0: 5.00mV, 1: 10.0mV,2: 20.0mV, 3: 50.0mV, 4: 100mV,5: 200mV, 6: 500mV, 7: 1V, 8: 2V, 9: 5V, */
	USHORT couple;			/*Couple:	0: AC, 1: DC, 2: GND*/
	USHORT probe;			/*Probe:	0: 1X, 1: 10X, 2: 100X, 3: 1000X*/
	USHORT invert;			/*Invert	0: OFF, 1: ON*/
	USHORT BW20M;			/*Band Width limit, 20M:		0: OFF, 1: ON*/
	USHORT BW100M;			/*Band Width limit, 20M:		0: OFF, 1: ON*/
	ULONG	voltDivValue;			/*the 100 times of the voltage. For example: if the voltDiv is 123, 
								the display string will be "1.23mV" */
	short 	vertPos;			/*The channel position displayed on the screen, the top is 0, and bottom is 199*/
	short 	vTrigPos;		/*The channel's trigger postion displayed on the screen, the top is 0, and the bottom is 199*/
	USHORT 	nData;			/*The number of data acquired from the hardware*/
	short 	horiPos;		/*The channel's horizontal trigger position displayed on the screen, the left is 0, and the right is 299*/
	USHORT 	hTriggerPos;	/*The channel's horizontal trigger position in the hardware, 0 ~ 18383(16K)*/
	USHORT 	timebase;		/*The channel's timebase,	0: 5.000ns, 1: 10.00ns,2: 20.00ns, 3: 50.00ns, 4: 100.0ns, 
														5: 200.0ns, 6: 500.0ns, 7: 1.000us, 8: 2.000us, 9: 5.000us, 
														10: 10.00us, 11: 20.00us, 12: 50.00us, 13: 100.0us, 14: 200.0us, 
														15: 500.0us, 16: 1.000ms, 17: 2.000ms, 18: 5.000ms, 19: 10.00ms, 
														20: 20.00ms, 21: 50.00ms, 22: 100.0ms, 23: 200.0ms, 24: 500.0ms, 
														25: 1.000s, 26: 2.000s, 27: 5.000s, 28: 10.00s, 29: 20.00s, 
														30: 50.00s, 31: 100.0s, 32: 200.0s, 33: 500.0s, 34: 1000s.*/
	USHORT 	voltDivType;	/*Corase or fine, 0: Corase, 1: fine*/
	USHORT 	bHasEmpty;		/*Be avilible when the DSO work in ROLL or scan mode. You should draw the points in the empty
								area. The area is defined by the next parameter -- emptyPos.
								0: Don't have empty area, 
								1: From emptyPos[0] to emptyPos[1] points are empty area*/
	short 	emptyPos[2];		
}CHANNEL;
/*Display struct*/
typedef struct _SCREEN_DISPLAY
{
	ULONG	xDotSpace;		/*The 1000 times of the distance between the each point display on the LCD screen.*/
	ULONG	xDisLeft;		/*The 1000 times of the left position, (0 ~ 300)*/
	ULONG	nDisData;		/*The number of the points display on the screen, (0 ~ 1200)*/
	USHORT	bDrawType;		/*Draw Type, 1: Normal, : Draw Dot*/
}SCREEN_DISPLAY;

typedef struct _HOLDOFF
{
	ULONG time;				/*Channge the holdoff time.*/
	short bOn;				/*turn on/off the holdoff, 0: OFF, 1: ON*/
}HOLDOFF;

/*Save the status when pressing 'stop'*/
typedef struct _STOPSTATUS
{
	short horiLevel;		/*the horiLevel*/
	CHANNEL ch[4];			/*the four channels's status*/
	USHORT timebase;		/*the timebase*/
}STOPSTATUS;
typedef struct _UPLOAD_DATA
{
	CHANNEL 			ch[4];						/*The four channels' status*/
	STOPSTATUS			stopStatus;					/*The status when pressing 'stop'*/
	MATH				math;						/*Math status*/
	TRIGGER 			trigger[3];					/*trigger system, 0: edge and pulse, 1: Ch1's trigger when ALT, 2: Ch2's trigger when ALT*/
	SCREEN_DISPLAY 		display[4];					/*Draw parameters*/
	USHORT				timebase;					/*timebase when edge or pulse trigger*/
	USHORT				function;				/*Type: 0: Scope, 1: Measurement*/
	USHORT 				status;				/*the status of the DSO1060, 0: Stop, 1: Run, 2: Auto, 3: Tri'd, 4: Wait*/
	short 				horiPos;					/*the horiLevel when edge or pulse trigger*/
	USHORT				triggerMode;				/*0: Edge Trigger, 1: Pulse Triger, 2: ALT Trigger*/
	USHORT				chSel;			/*The current selected channel */
	USHORT				horiFormat;			/*0: Y-T Mode, 1: X-Y Mode, 2: ROLL Mode*/
	USHORT				SamplingMode;				/*0: Real Sample, 1: ETS*/
	USHORT				hTriggerPos;//0 ~ 16383		/*Trigger Position in the hardware*/
	HOLDOFF 			holdOff;					/*Hold off*/
}UPLOAD_DATA;


/***********************************************************
*Function:		DSOSetStatus
*Description:	Set the current running status, Run or Stop
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				BOOLEAN bStatus:				0: STOP, 1: RUN
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetStatus(HT_DEVICE_ID iDeviceID,BOOLEAN bStatus);
/***********************************************************
*Function:		DSOAutoSetup
*Description:	Start autoset
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOAutoSetup(HT_DEVICE_ID iDeviceID);
/***********************************************************
*Function:		DSOFactorySetup
*Description:	Get the factory setup
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOFactorySetup(HT_DEVICE_ID iDeviceID);
//Hori
/***********************************************************
*Function:		DSOSetTimeBase
*Description:	Set timebase 
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set timebase. (0 ~ 3)
												0: When ALT trigger, set CH1 timebase. Otherwise, set all timebase
												1: When ALT trigger, set CH2 timebase. Otherwise, set all timebase
												2: When ALT trigger, set Math timebase. Otherwise, set all timebase
												3: Set REL timebase
				INT8U iTimebase:				the timebase value to set.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTimeBase(HT_DEVICE_ID iDeviceID, INT8U iChannel,INT8U iTimeBase);
/***********************************************************
*Function:		DSOSetFormat
*Description:	Set Horizontal format
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iFormat:					Set the horizontal format: 0: Y-T, 1: X-Y, 2: ROLL
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetHoriFormat(HT_DEVICE_ID iDeviceID, INT8U iFormat);
/***********************************************************
*Function:		DSOSetHTriggerPos
*Description:	Set Horizontal Trigger Position
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U iHTriggerPos:			the trigger level to set, (0 ~ 300)
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetHTriggerPos(HT_DEVICE_ID iDeviceID, INT8U iChannel, INT16U iHTriggerPos);
//vert
/***********************************************************
*Function:		DSOSetCHEnable
*Description:	Enable/Disable the channel
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U bEnable:				0: Disable, 1: Enable
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetCHEnable(HT_DEVICE_ID iDeviceID,INT8U iChannel, BOOLEAN bEnable);
/***********************************************************
*Function:		DSOSetVOLTDIV
*Description:	Set the voltage/div
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U iVoltDIV:				see the cur_volt parameter in the 'CHANNEL' struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetVOLTDIV(HT_DEVICE_ID iDeviceID,INT8U iChannel,INT8U iVoltDIV);
/***********************************************************
*Function:		DSOSetCoupling
*Description:	Set the couple
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U iCoupling:				0: AC, 1: DC, 2: GND
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetCoupling(HT_DEVICE_ID iDeviceID, INT8U iChannel,INT8U iCoupling);
/***********************************************************
*Function:		DSOSetProbe
*Description:	Set the couple
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U iProbe:					0: 1X, 1: 10X, 2: 100X, 3: 1000X
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetProbe(HT_DEVICE_ID iDeviceID, INT8U iChannel, INT8U iProbe);
/***********************************************************
*Function:		DSOSetBWLimit
*Description:	Set the band width limit, 20M
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U bEnable:				0: Disable, 1: Enable
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetBW20M(HT_DEVICE_ID iDeviceID,INT8U iChannel ,BOOLEAN bEnable);
/***********************************************************
*Function:		DSOSetBW100M
*Description:	Set the band width limit, 100M
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U bEnable:				0: Disable, 1: Enable
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetBW100M(HT_DEVICE_ID iDeviceID,INT8U iChannel ,BOOLEAN bEnable);

/***********************************************************
*Function:		DSOSetCoarseOrFine
*Description:	Set corase or fine of the channel.
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U iCoarse:				0: Coarse, 1: Fine
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetCoarseOrFine(HT_DEVICE_ID iDeviceID, INT8U iChannel , INT8U iCoarse);
/***********************************************************
*Function:		DSOSetInvert
*Description:	Set the channel invert or not
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				UINT16U bInvert:				0: Normal, 1: Invert
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetInvert(HT_DEVICE_ID iDeviceID,INT8U iChannel ,BOOLEAN bInvert);
/***********************************************************
*Function:		DSOResetChannel
*Description:	Move the channel to the center of the screen
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOResetChannel(HT_DEVICE_ID iDeviceID,INT8U iChannel);
/***********************************************************
*Function:		DSOSetChannelLeverPos
*Description:	Set the channel's vertical position
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					the channel to set, 0:CH1, 1:CH2, 2:MATH, 3:REF
				INT8U iLeverPos:				(0 ~ 199), the top is 0, and the bottom is 199
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetChannelLeverPos(HT_DEVICE_ID iDeviceID,INT8U iChannel,INT16U iLeverPos);
/***********************************************************
*Function:		DSOSetMathOperator
*Description:	Change the math operate
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iOperator:				0: +, 1: -, 2: *, 3: /, 4: FFT
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetMathOperator(HT_DEVICE_ID iDeviceID,INT8U iOperator);
/***********************************************************
*Function:		DSOSetMathSource
*Description:	Change the math sourceA or SourceB
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iType:					0: SourceA, 1: SourceB
				INT8U iSource:					0: CH1, 1: CH2
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetMathSource(HT_DEVICE_ID iDeviceID,INT8U iType, INT8U iSource);
/***********************************************************
*Function:		DSOSetVoltDIVChange
*Description:	Channge the voltage/div
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iType:					0: Decrease, 1: Increase
				INT8U iSource:					0: CH1, 1: CH2, 2: MATH, 3: REF
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetVoltDIVChange(HT_DEVICE_ID iDeviceID,INT8U iType,INT8U iChannel);
//Trig
/***********************************************************
*Function:		DSOSetTriggerMode
*Description:	Set the trigger mode
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iMode:					0: Edge, 1: Pulse, 2: ALT
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTriggerMode(HT_DEVICE_ID iDeviceID,INT8U iMode);
/***********************************************************
*Function:		DSOSetTriggerHFReject
*Description:	Enable/Disable the trigger HF Reject
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iCh:						When ALT trigger mode: 0: CH1, 1: CH2, 
												When edge or pulse trigger mode: invalidate.
				bEnable:						0: Disable, 1: Enable					
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTriggerHFReject(HT_DEVICE_ID iDeviceID,INT8U iCh, BOOLEAN bEnable);

/***********************************************************
*Function:		DSOSetTriggerSource
*Description:	Set the trigger source, when edge or pulse trigger.
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iSource:					0: CH1, 1: CH2
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTriggerSource(HT_DEVICE_ID iDeviceID,INT8U iSource);
/***********************************************************
*Function:		DSOSetTriggerSweep
*Description:	Set the trigger sweep
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iSweep:					0: Auto, 1: Normal, 2: Single
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTriggerSweep(HT_DEVICE_ID iDeviceID,INT8U iSweep);
/***********************************************************
*Function:		DSOSetVTriggerLeverPos
*Description:	Set the vertical trigger position
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					0: CH1, 1: CH2
				INT16U iPos:					0 ~ 199, the top is 0, the bottom is 199
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetVTriggerLeverPos(HT_DEVICE_ID iDeviceID,INT8U iChannel,INT16U iPos);
/***********************************************************
*Function:		DSOSetTriggerSlope
*Description:	Set the trigger slope
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					When edge trigger, the iChannel is invalidate
												When ALT trigger, 0: CH1, 1: CH2
				INT16U iSlope:					0: Rise, 1: Fall
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetTriggerSlope(HT_DEVICE_ID iDeviceID, INT8U iChannel, INT8U iSlope);
/***********************************************************
*Function:		DSOSetPulseTriggerCondition
*Description:	Set the pulse trigger condition
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					When edge trigger, the iChannel is invalidate
												When ALT trigger, 0: CH1, 1: CH2
				INT16U iCondition:				0: +Less, 1: +Equal, 2: +More, 3: -Less, 4: -Equal, 5: -More
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetPulseTriggerCondition(HT_DEVICE_ID iDeviceID,INT8U iChannel, INT8U iCondition);
/***********************************************************
*Function:		DSOSetPulseTriggerTime
*Description:	Set the pulse trigger setting time
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					When edge trigger, the iChannel is invalidate
												When ALT trigger, 0: CH1, 1: CH2
				INT32U iTime:					see the 'pluseValue' parameter in the TRIGGER struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetPulseTriggerTime(HT_DEVICE_ID iDeviceID,INT8U iChannel, INT32U iTime);
/***********************************************************
*Function:		DSOSetALTTrigType
*Description:	Set the ALT trigger mode
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iChannel:					0: CH1, 1: CH2
				INT8U iMode:					0: Edge, 1: Pulse
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetALTTrigType(HT_DEVICE_ID iDeviceID, INT8U iCh, INT8U iMode);
//FFT
/***********************************************************
*Function:		DSOSetFFTSource
*Description:	Set the FFT Source
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iFFTSource:				0: CH1, 1: CH2
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetFFTSource(HT_DEVICE_ID iDeviceID,INT8U iFFTSource);
/***********************************************************
*Function:		DSOSetFFTSource
*Description:	Set the FFT Window
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iFFTWindow:				see the 'fftWindow' parameter in the MATH struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetFFTWindow(HT_DEVICE_ID iDeviceID,INT8U iFFTWindow);
/***********************************************************
*Function:		DSOSetFFTScale
*Description:	Set the FFT Scale
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iFFTScale:				see the 'fftScale' parameter in the MATH struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOSetFFTScale(HT_DEVICE_ID iDeviceID,INT8U iFFTScale);
//
/***********************************************************
*Function:		DSOUploadSetting
*Description:	Get all of the setting and data to display
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				UPLOAD_DATA* upData:			setting and data
				USHORT* pCh1DisData:			Ch1's data to display, the size of 1200
				USHORT* pCh2DisData:			Ch1's data to display, the size of 1200
				USHORT* pMathDisData:			Ch1's data to display, the size of 1200
				USHORT* pRefDisData:			Ch1's data to display, the size of 1200
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DSOGetAllSetting(HT_DEVICE_ID iDeviceID,UPLOAD_DATA* upData,
										 USHORT* pCh1DisData, USHORT* pCh2DisData,
										 USHORT* pMathDisData, USHORT* pRefDisData);
/***********************************************************
*Function:		DSOGetCh12Data
*Description:	Get the CH1 and Ch2 memory data from DSO, 16K or 32K
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U* pCh1Data:				CH1 data
				INT8U* pCh2Data:				CH2 data
				ULONG nCh1Datalen:				the len of the CH1 data which defined by nData in the struct CHANNEL.
				ULONG nCh2Datalen:				the len of the CH2 data which defined by nData in the struct CHANNEL.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-11-02
**********************************************************/
DLL_API HTSTATUS WINAPI DSOGetCh12Data(HT_DEVICE_ID iDeviceID, INT8U* pCh1Data, INT8U* pCh2Data, 
									   ULONG nCh1DataLen, ULONG nCh2DataLen);
/***********************************************************
*Function:		DSOGetCh12Data
*Description:	Get the REF memory data from DSO, 16K or 32K
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U* pREFData:				REF data
				ULONG nDatalen:					the len of the CH data which defined by nData in the struct CHANNEL.
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-11-02
**********************************************************/
DLL_API HTSTATUS WINAPI DSOGetChREFData(HT_DEVICE_ID iDeviceID, INT8U* pREFData, ULONG nDataLen);
	

////////DMM
/*DMM Type*/
#define DMM_VOLTAGE	0	/*Voltage*/
#define DMM_CURRENT 1	/*Current*/
#define DMM_OHM 2		/*Resistance*/
#define DMM_DIODE 3		/*Diode*/
#define DMM_CONTI 4		/*CONTI*/
#define DMM_CAP 5		/*Capacitance*/
/*Couple*/
#define DMM_DC	0//		/*DC*/
#define DMM_AC	1//		/*AC*/
/*Mode*/
#define DMM_AUTO	0	/*Auto*/
#define DMM_MANUAL	1	/*Manual*/
/*Current Type*/
#define DMM_A_A		0	/*A*/
#define DMM_A_MA	1	/*mA*/

//
/*Unit*/
#define DMM_UNIT_P		0	/*'p'*/
#define DMM_UNIT_n		1	/*'n'*/
#define DMM_UNIT_mu		2	/*'u'*/
#define DMM_UNIT_m		3	/*'m'*/
#define DMM_UNIT_k		4	/*'k'*/
#define DMM_UNIT_M		5	/*'M'*/
#define DMM_UNIT_G		6	/*'G'*/
#define DMM_UNIT_NULL	7	/**/

/*Unit Type*/
#define DMM_UNIT_V	0		/*'V'*/
#define DMM_UNIT_A	1		/*'A'*/
#define DMM_UNIT_R	2		/*ohm*/
#define DMM_UNIT_F	3		/*'F'*/

/*Bar sign*/
#define DMM_SIGN_POS	0	
#define DMM_SIGN_NEG	1	
/*Digital Measurement information*/
typedef struct _DMM_VALUE
{
	INT8U	value[4];		/*The char value display on the screen. For example,if the value is {1,2,3,4}, 
								the string "1234" will display on the screen*/
	float	flValue;		/*the value Display on the screen*/
	INT8U	iDotPos;		/*the dot pos of the value, */
	INT8U	iUnit;			/*see the unit definition*/
	INT8U	iUnitType;		/*see the unit type definition*/
	INT8U   iSign;			/*the sign of the value*/
}DMM_VALUE;
typedef struct _DMM_INFO
{
	INT8U	iType;			/*0: Voltage, 1: Current, 2: Resistance, 3: Diode, 4: Conti, 5: Capacitance*/
	BOOLEAN bOverflow;		/*whether overflow or not */	
	INT8U	iDCAC;			/*couple, 0: DC, 1: AC*/
	INT8U	iMode;			/*Mode: 0: AUTO, 1: Manual*/
	BOOLEAN	bRel;			/*0: Normal, 1: REL*/
	INT8U	iRange;			/*the range index int the array*/
							/*	Voltage:	{60.00mV, 600.0mV, 6.000V, 60.00V, 600.0V, 6000V}
								Crrent: 	{60.00mA, 600.0mA}
								Resistance:	{600.0, 6.000K, 60.00K, 600.0K, 6.000M, 60.00M}*/
	INT8U	bAma;			/*When current, 0: A, 1: mA*/
	INT8U	iBar;			/*Bar value*/
	INT8U	iBarSign;		/*Bar sign: 0: Positive, 1: Negative*/
	DMM_VALUE value;		/*value*/
	DMM_VALUE relValue;		/*The rel's value*/
}DMM_INFO, *PDMM_INFO;
/***********************************************************
*Function:		DMMGetInfo
*Description:	Get the measurement information
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				PDMM_INFO info:					DMM's information
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMGetInfo(HT_DEVICE_ID iDeviceID, PDMM_INFO info);	
/***********************************************************
*Function:		DMMSetMeasureMode
*Description:	Set the DMM type
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iMode:					0: Voltage, 1: Current, 2: Resistance, 3: Diode, 4: CONTI, 5:Capacitance 
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetMeasureMode(HT_DEVICE_ID iDeviceID,INT8U iMode);
//V
/***********************************************************
*Function:		DMMSetVoltACDC
*Description:	Set the DMM Voltage Couple
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iACDC:					0: DC, 1: AC 
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetVoltACDC(HT_DEVICE_ID iDeviceID, INT8U iACDC);
/***********************************************************
*Function:		DMMSetVoltRel
*Description:	Set the DMM Voltage REL
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iACDC:					0: Normal, 1: REL
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetVoltRel(HT_DEVICE_ID iDeviceID, BOOLEAN bRel);
/***********************************************************
*Function:		DMMSetVoltMode
*Description:	Set the DMM Voltage Mode
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iMode:					0: AUTO, 1: Manual
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetVoltMode(HT_DEVICE_ID iDeviceID, INT8U iMode);
/***********************************************************
*Function:		DMMSetVoltRange
*Description:	Set the DMM Voltage Range
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iRange:					see the 'iRange' in the DMM_INFO struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetVoltRange(HT_DEVICE_ID iDeviceID, INT8U iRange);
//A
/***********************************************************
*Function:		DMMSetCurrentACDC
*Description:	Set the DMM Current Couple
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iACDC:					0: DC, 1: AC
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCurrentACDC(HT_DEVICE_ID iDeviceID, INT8U iACDC);
/***********************************************************
*Function:		DMMSetCurrentRel
*Description:	Set the DMM Current REL
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U bRel:					0: Normal, 1: REL
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCurrentRel(HT_DEVICE_ID iDeviceID, BOOLEAN bRel);
/***********************************************************
*Function:		DMMSetCurrentMode
*Description:	Set the DMM Current Mode
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iMode:					0: AUTO, 1: Manual
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCurrentMode(HT_DEVICE_ID iDeviceID, INT8U iMode);
/***********************************************************
*Function:		DMMSetCurrentRange
*Description:	Set the DMM Current Range
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iRange:					see the 'iRange' in the DMM_INFO struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCurrentRange(HT_DEVICE_ID iDeviceID, INT8U iRange);
/***********************************************************
*Function:		DMMSetCurrentAmA
*Description:	Set the DMM Current type
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iAmA:						0: A, 1: mA
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCurrentAmA(HT_DEVICE_ID iDeviceID, INT8U iAmA);
//
/***********************************************************
*Function:		DMMSetOHMRel
*Description:	Set the DMM OHM REL
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U bRel:						0: Normal, 1: REL
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetOHMRel(HT_DEVICE_ID iDeviceID, BOOLEAN bRel);
/***********************************************************
*Function:		DMMSetOHMRange
*Description:	Set the DMM OHM Range
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iRange:					see the 'iRange' in the DMM_INFO struct
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetOHMRange(HT_DEVICE_ID iDeviceID, INT8U iRange);
/***********************************************************
*Function:		DMMSetOHMMode
*Description:	Set the DMM OHM Mode
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U iMode:					0: AUTO, 1: Manual
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetOHMMode(HT_DEVICE_ID iDeviceID, INT8U iMode);
//
/***********************************************************
*Function:		DMMSetCapRel
*Description:	Set the DMM CAP REL
*Parameters:	HT_DEVICE_ID iDeivceID:			the id of the device which is made by CREATE_DEVID.
				INT8U bRel:						0: Normal, 1: REL
*Return: 		HT_OK		Success
				HT_ERROR	Failed
*Author:		Hantek
*Create Date:	2009-09-14 
**********************************************************/
DLL_API HTSTATUS WINAPI DMMSetCapRel(HT_DEVICE_ID iDeviceID, BOOLEAN bRel);
#endif