// Hard.cpp: implementation of the CHard class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "VC.h"
#include "Hard.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CHard::CHard()
{
	m_bConnect = 0;
	m_bHard = 0;
	m_iDevice = 0;
	m_iFunc = HT_DSO;
	InitMsgQueue();
}

CHard::~CHard()
{

}


void CHard::Process()
{
	HT_DEVICE_ID id = CREATE_DEVID(m_iDevice, DEV_USB);
	DSO_MESSAGE msg = {0, 0};

	if (m_bHard == 0)
		return;	
	//Check the hardware is connecting or not
	if (HT_OK != HTUSBCheckConnect(id))
	{
		m_bConnect = 0;
		return;
	}
//	return;
	if (m_bConnect == 0)
	{
	//	SearchHardware();
		HTGetDeviceInfo(id, &m_devInfo );
		m_bConnect = 1;
	}
	m_iFunc = HTGetFunction(id);
	if (m_queMsg.size() > 0)
	{
		ProcessMsg(id, PopMsg());
	}
	if (m_iFunc == HT_DSO)
	{
		m_dsoFunc.GetInfo(id);
	}
	else if(m_iFunc == HT_DMM)
	{
		m_dmmFunc.GetInfo(id);
	}	
}

void CHard::InitMsgQueue()
{
	m_queMsg.clear();
}
void CHard::PushMsg(DSO_MESSAGE msg)
{
	m_queMsg.push_back(msg);
}
DSO_MESSAGE CHard::PopMsg()
{
	DSO_MESSAGE msg = {0, 0};
	if (m_queMsg.size() == 0)
		return msg;
	else
	{
		msg =  m_queMsg.front();
		m_queMsg.pop_front();
		return msg;
	}		
}
BOOL CHard::SearchHardware()	/*search hardware*/
{
	int nHard = HTGetUSBDeviceList(m_usbStatus);
	int i;
	if (nHard == 0)
	{
		m_bHard = 0;
		m_bConnect = 0;
		return 0 ;
	}
	m_bHard = 1;
	m_bConnect = 1;
	for (i = 0; i < MAX_DEV_NUM; i++)
	{
		if (m_usbStatus[i] == 1)
		{
			m_iDevice = i;	//Set the device id
			break;
		}
	}
	HTGetDeviceInfo(CREATE_DEVID(m_iDevice, DEV_USB), &m_devInfo );
	return 1;
}
BOOL CHard::SetHardParam(int msg, int value)
{
	DSO_MESSAGE message;
	message.msg = msg;
	message.value = value;
	PushMsg(message);
	return 1;
}
CString CHard::GetSerialNumber()
{
	CString str;
	if (m_bConnect == 0)
		str = "";
	else
		str.Format("%s", m_devInfo.szSerial);
	return str;
}

BOOL CHard::ProcessMsg(int id, DSO_MESSAGE msg)	/*process message*/
{
	int m = msg.msg;
	int v = msg.value;
	int type;
	BOOL bChange;
	if (m == MSG_CHANGE_FUNC)
	{
		HTChangeFunction(id, v);
	}
	//DSO
	else if (m == MSG_DSO_VOLTAGE_CH1)
	{
		DSOSetVOLTDIV(id, 0, v);
	}
	else if (m == MSG_DSO_VOLTAGE_CH2)
	{
		DSOSetVOLTDIV(id, 1, v);
	}
	else if (m == MSG_DSO_TIMEBASE)
	{
		DSOSetTimeBase(id, 0, v);
	}
	else if (m == MSG_DSO_TRIGGERSOURCE)
	{
		DSOSetTriggerSource(id, v);
	}
	else if (m == MSG_DSO_TRIGGERMODE)
	{
		DSOSetTriggerMode(id, v);
	}
	else if (m == MSG_DSO_CHPOS_CH1)
	{
		DSOSetChannelLeverPos(id, 0, v);
	}
	else if (m == MSG_DSO_CHPOS_CH2)
	{
		DSOSetChannelLeverPos(id, 1, v);
	}
	else if (m == MSG_DSO_TRIGPOS_CH1)
	{
		DSOSetVTriggerLeverPos(id, 0, v);
	}
	else if (m == MSG_DSO_TRIGPOS_CH2)
	{
		DSOSetVTriggerLeverPos(id, 1, v);
	}
	else if (m == MSG_DSO_AUTOSET)
	{
		DSOAutoSetup(id);
	}
	//DMM
	else if (m == MSG_DMM_TYPE)
	{
		DMMSetMeasureMode(id, v);
	}
	else if (m == MSG_DMM_DCAC)
	{
		type = m_dmmFunc.DMMGetType(bChange);
		if (type == DMM_VOLTAGE)
			DMMSetVoltACDC(id, v);
		else if (type == DMM_CURRENT)
			DMMSetCurrentACDC(id, v);
	}
	else if (m == MSG_DMM_AUTOMANUAL)	//Auto, manual
	{
		type = m_dmmFunc.DMMGetType(bChange);
		if (type == DMM_VOLTAGE)
			DMMSetVoltMode(id, v);
		else if (type == DMM_CURRENT)
			DMMSetCurrentMode(id, v);
		else if (type == DMM_OHM)
			DMMSetOHMMode(id, v);
	}
	else if (m == MSG_DMM_AMA)
	{
		DMMSetCurrentAmA(id, v);
	}
	else if (m == MSG_DMM_REL)
	{
		type = m_dmmFunc.DMMGetType(bChange);
		if (type == DMM_VOLTAGE)
			DMMSetVoltRel(id, v);
		else if (type == DMM_CURRENT)
			DMMSetCurrentRel(id, v);
		else if (type == DMM_OHM)
			DMMSetOHMRel(id, v);
		else
			DMMSetCapRel(id, v);	
	}
	else if (m == MSG_DMM_RANGE)
	{
		type = m_dmmFunc.DMMGetType(bChange);
		if (type == DMM_VOLTAGE)
			DMMSetVoltRange(id, v);
		else if (type == DMM_CURRENT)
			DMMSetCurrentRange(id, v);
		else if (type == DMM_OHM)
			DMMSetOHMRange(id, v);
	}

	return 0;
}